@@ -23,7 +23,7 @@ REGEXES = set([
     ("word", re.compile(r"(\w|\.)+", re.U)),
     ("mac", re.compile(r'^(ma?c)(\w{2,})', re.I | re.U)),
     ("initial", re.compile(r'^(\w\.|[A-Z])?$', re.U)),
-    ("quoted_word", re.compile(r'\'([^\s]*?)\'', re.U)),
+    ("quoted_word", re.compile(r'(?<!\w)\'([^\s]*?)\'(?!\w)', re.U)),
     ("double_quotes", re.compile(r'\"(.*?)\"', re.U)),
     ("parenthesis", re.compile(r'\((.*?)\)', re.U)),
     ("roman_numeral", re.compile(r'^(X|IX|IV|V?I{0,3})$', re.I | re.U)),
