@@ -36,7 +36,10 @@ class HumanName(object):
 
     Instantiation assigns to ``full_name``, and assignment to
     :py:attr:`full_name` triggers :py:func:`parse_full_name`. After parsing the
-    name, these instance attributes are available.
+    name, these instance attributes are available. Alternatively, you can pass 
+    any of the instance attributes to the constructor method and skip the parsing
+    process. If any of the the instance attributes are passed to the constructor 
+    as keywords, :py:func:`parse_full_name` will not be performed. 
 
     **HumanName Instance Attributes**
 
@@ -56,6 +59,12 @@ class HumanName(object):
     :param str string_format: python string formatting
     :param str initials_format: python initials string formatting
     :param str initials_delimter: string delimiter for initials
+    :param str first: first name
+    :param str middle: middle name
+    :param str last: last name
+    :param str title: The title or prenominal
+    :param str suffix: The suffix or postnominal
+    :param str nickname: Nicknames
     """
 
     C = CONSTANTS
@@ -77,7 +86,9 @@ class HumanName(object):
     _full_name = ''
 
     def __init__(self, full_name="", constants=CONSTANTS, encoding=DEFAULT_ENCODING,
-                 string_format=None, initials_format=None, initials_delimiter=None):
+                 string_format=None, initials_format=None, initials_delimiter=None,
+                 first=None, middle=None, last=None, title=None, suffix=None,
+                 nickname=None):
         self.C = constants
         if type(self.C) is not type(CONSTANTS):
             self.C = Constants()
@@ -86,8 +97,17 @@ class HumanName(object):
         self.string_format = string_format or self.C.string_format
         self.initials_format = initials_format or self.C.initials_format
         self.initials_delimiter = initials_delimiter or self.C.initials_delimiter
-        # full_name setter triggers the parse
-        self.full_name = full_name
+        if (first or middle or last or title or suffix or nickname):
+            self.first = first
+            self.middle = middle
+            self.last = last
+            self.title = title
+            self.suffix = suffix
+            self.nickname = nickname
+            self.unparsable = False
+        else:
+            # full_name setter triggers the parse
+            self.full_name = full_name
 
     def __iter__(self):
         return self
@@ -141,6 +161,9 @@ class HumanName(object):
             return self.collapse_whitespace(_s).strip(', ')
         return " ".join(self)
 
+    def __hash__(self):
+        return hash(str(self))
+
     def __str__(self):
         if sys.version_info[0] >= 3:
             return self.__unicode__()
@@ -150,7 +173,7 @@ class HumanName(object):
         if self.unparsable:
             _string = "<%(class)s : [ Unparsable ] >" % {'class': self.__class__.__name__, }
         else:
-            _string = "<%(class)s : [\n\ttitle: '%(title)s' \n\tfirst: '%(first)s' \n\tmiddle: '%(middle)s' \n\tlast: '%(last)s' \n\tsuffix: '%(suffix)s'\n\tnickname: '%(nickname)s'\n]>" % {
+            _string = "<%(class)s : [\n\ttitle: %(title)r \n\tfirst: %(first)r \n\tmiddle: %(middle)r \n\tlast: %(last)r \n\tsuffix: %(suffix)r\n\tnickname: %(nickname)r\n]>" % {
                 'class': self.__class__.__name__,
                 'title': self.title or '',
                 'first': self.first or '',
@@ -191,7 +214,7 @@ class HumanName(object):
 
     def __process_initial__(self, name_part, firstname=False):
         """
-            Name parts may include prefixes or conjuctions. This function filters these from the name unless it is
+            Name parts may include prefixes or conjunctions. This function filters these from the name unless it is
             a first name, since first names cannot be conjunctions or prefixes.
         """
         parts = name_part.split(" ")
@@ -591,9 +614,9 @@ class HumanName(object):
                     nxt = None
 
                 # title must have a next piece, unless it's just a title
-                if self.is_title(piece) \
+                if not self.first \
                         and (nxt or p_len == 1) \
-                        and not self.first:
+                        and self.is_title(piece):
                     self.title_list.append(piece)
                     continue
                 if not self.first:
@@ -641,9 +664,9 @@ class HumanName(object):
                     except IndexError:
                         nxt = None
 
-                    if self.is_title(piece) \
+                    if not self.first \
                             and (nxt or len(pieces) == 1) \
-                            and not self.first:
+                            and self.is_title(piece):
                         self.title_list.append(piece)
                         continue
                     if not self.first:
@@ -681,9 +704,9 @@ class HumanName(object):
                     except IndexError:
                         nxt = None
 
-                    if self.is_title(piece) \
+                    if not self.first \
                             and (nxt or len(post_comma_pieces) == 1) \
-                            and not self.first:
+                            and self.is_title(piece):
                         self.title_list.append(piece)
                         continue
                     if not self.first:
